/* $Id: sm_pfq.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */

#include <stdlib.h>

#include "sylimits.h"
#include "data.h"
#include "error.h"

void
privinit_pfq()
{
    fatal("pfq module not available");
}
void
init_pfq(struct stream *st)
{
    fatal("pfq module not available");
}
void
gets_pfq()
{
    fatal("pfq module not available");
}
int
get_pfq(char *b, int l, struct stream *st)
{
    fatal("pfq module not available");

    /* NOT REACHED */
    return 0;
}
